import pandas as pd

CONFIG = 'config.csv'

WAREHOUSE = {
    'warehouse': 'sub',
    'feed_se': 'https://panel-b.baselinker.com/inventory_export.php?hash=30aababdd7a417770c7df35021099fa9'
}

def split_dataframe(df, num_chunks = 3): 
    chunks = list()
    for i in range(num_chunks):
        chunk_end = int(i+1 * df.shape[0]/num_chunks)
        chunk_start = int(i * df.shape[0]/num_chunks)
        chunks.append(df[chunk_start:(i+1)*chunk_end])
    return chunks

def read_csv(csv_file, separator = ';', encoding = 'utf-8', form = 'records', cols = None, to_dict = True):
    """
    Function to read csv file to list of dictionaries

    Args:
        csv_file (str): file name of csv to read
        separator (str, optional): separator used when reading csv file. Defaults to ';'.
        encoding (str, optional): encoding used when reading csv_file. Defaults to 'utf-8'.
        form (str, optional): form of reading csv file. Defaults to 'records', every record from CSV as dictionary in a list.
        cols (list, optional): which columns read to list of dictionaries

    Returns:
        list: list of dictionaries, where each dictionary is a record from csv
    """
    if to_dict:
        return pd.read_csv(csv_file, sep = separator, encoding = encoding, usecols = cols, keep_default_na=False, low_memory=False).to_dict(form)
    else:
        return pd.read_csv(csv_file, sep = separator, encoding = encoding, usecols = cols, keep_default_na=False, low_memory=False)

def remove_duplicates(list_of_dicts, on):
    return pd.DataFrame(list_of_dicts).drop_duplicates(subset=on).to_dict('records')

def save_csv(csv_file, list_of_dicts, separator = ';', encoding = 'utf-8', index = False, cols = None, mode = 'w', header = True):
    """
    Function to save list of dictionaries to csv file

    Args:
        csv_file (str): file name of csv to read
        list_of_dicts (list): list of dictionaries to be saved to csv (one dictionary = one record)
        separator (str, optional): separator used when reading csv file. Defaults to ';'.
        encoding (str, optional): encoding used when reading csv_file. Defaults to 'utf-8'.
        cols (list, optional): which columns read to list of dictionaries

    Returns:
        str: resulting csv formatted as string
    """    
    return pd.DataFrame(list_of_dicts).to_csv(csv_file, sep = separator, encoding = encoding, index = index, columns = cols, mode = mode, header = header)

def join_dfs(left_df = None, right_df = None, left_on = None, right_on = None, how = None, indicator = True):
    return pd.merge(left_df, right_df, left_on = left_on, right_on = right_on, how = how, indicator = indicator)